# Sashimi Package

[![PyPI version](https://badge.fury.io/py/sashimi.svg)](https://badge.fury.io/py/sashimi)  [![codecov](https://codecov.io/gh/doerlbh/sashimi/branch/main/graph/badge.svg?token=)](https://codecov.io/gh/doerlbh/tba)  [![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

Python library for benchmarking spatio-temporal saliency prediction on videos, images, and options including face and eye detections. It predicts where human eyes might look at in naturalistic settings.

Created by [Baihan Lin](https://www.baihan.nyc), Columbia University
